document.addEventListener('DOMContentLoaded', () => {
  const rangeInputs = document.querySelectorAll('input[type="range"]');
  const calculateBtn = document.getElementById('calculate');
  const resultDiv = document.getElementById('result');

  // Update range input values
  rangeInputs.forEach(input => {
    input.addEventListener('input', (e) => {
      e.target.nextElementSibling.textContent = e.target.value;
    });
  });

  // Calculate decision
  calculateBtn.addEventListener('click', () => {
    const salary = parseInt(document.getElementById('salary').value);
    const family = parseInt(document.getElementById('family').value);
    const career = parseInt(document.getElementById('career').value);
    const lifestyle = parseInt(document.getElementById('lifestyle').value);

    // Calculate weighted score
    const sfScore = (salary * 0.9 + family * 0.3 + career * 0.8 + lifestyle * 0.6) / 2.6;
    const hydScore = (salary * 0.5 + family * 0.9 + career * 0.6 + lifestyle * 0.8) / 2.8;

    let decision = '';
    let color = '';

    if (Math.abs(sfScore - hydScore) < 1) {
      decision = "This is a close call! Consider making a pros and cons list specific to your situation.";
      color = "#ffa502";
    } else if (sfScore > hydScore) {
      decision = "Based on your priorities, staying in San Francisco might be better for you.";
      color = "#2ed573";
    } else {
      decision = "Based on your priorities, moving to Hyderabad might be better for you.";
      color = "#2ed573";
    }

    resultDiv.style.backgroundColor = color;
    resultDiv.style.color = color === "#ffa502" ? "#000" : "#fff";
    resultDiv.innerHTML = `
      <p>${decision}</p>
      <small>SF Score: ${sfScore.toFixed(1)} | Hyderabad Score: ${hydScore.toFixed(1)}</small>
    `;
  });

  // Smooth scrolling for navigation
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
});
